Stan Math Library: stan/math/prim/scal/fun/is_uninitialized.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_uninitialized.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_IS_UNINITIALIZED_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_IS_UNINITIALIZED_HPP
3
4 namespace stan {
5
6 namespace math {
7
18 template <typename T>
19 inline bool is_uninitialized(T x) {
20 return false;
21 }
22
23 }
24 }
25 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::is_uninitialized
bool is_uninitialized(T x)
Returns true if the specified variable is uninitialized.
Definition: is_uninitialized.hpp:19

[ Stan Home Page ] © 2011–2016, Stan Development Team.